|
From: <caw...@us...> - 2007-02-19 21:45:54
|
Revision: 1978
http://svn.sourceforge.net/rubyeclipse/?rev=1978&view=rev
Author: cawilliams
Date: 2007-02-19 13:45:51 -0800 (Mon, 19 Feb 2007)
Log Message:
-----------
Modified Paths:
--------------
trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/core/LoadpathContainerInitializer.java
Modified: trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/core/LoadpathContainerInitializer.java
===================================================================
--- trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/core/LoadpathContainerInitializer.java 2007-02-19 21:45:47 UTC (rev 1977)
+++ trunk/org.rubypeople.rdt.core/src/org/rubypeople/rdt/core/LoadpathContainerInitializer.java 2007-02-19 21:45:51 UTC (rev 1978)
@@ -37,17 +37,17 @@
* In case multiple container initializers collide on the same container ID, the first
* registered one will be invoked.
*
- * @see IClasspathEntry
- * @see IClasspathContainer
- * @since 2.0
+ * @see ILoadpathEntry
+ * @see ILoadpathContainer
+ * @since 0.9.0
*/
public abstract class LoadpathContainerInitializer {
/**
* Creates a new classpath container initializer.
*/
public LoadpathContainerInitializer() {
// a classpath container initializer must have a public 0-argument constructor
}
/**
@@ -119,9 +119,9 @@
* @return returns <code>true</code> if the container can be updated
* @since 2.1
*/
- public boolean canUpdateClasspathContainer(IPath containerPath, IRubyProject project) {
+ public boolean canUpdateLoadpathContainer(IPath containerPath, IRubyProject project) {
- // By default, classpath container initializers do not accept updating containers
+ // By default, loadpath container initializers do not accept updating containers
return false;
}
@@ -144,12 +144,12 @@
* @param containerSuggestion a suggestion to update the corresponding container definition
* @throws CoreException when <code>JavaCore#setClasspathContainer</code> would throw any.
* @see JavaCore#setClasspathContainer(IPath, IJavaProject[], IClasspathContainer[], org.eclipse.core.runtime.IProgressMonitor)
- * @see ClasspathContainerInitializer#canUpdateClasspathContainer(IPath, IJavaProject)
- * @since 2.1
+ * @see ClasspathContainerInitializer#canUpdateLoadpathContainer(IPath, IJavaProject)
+ * @since 0.9.0
*/
- public void requestClasspathContainerUpdate(IPath containerPath, IRubyProject project, ILoadpathContainer containerSuggestion) throws CoreException {
+ public void requestLoadpathContainerUpdate(IPath containerPath, IRubyProject project, ILoadpathContainer containerSuggestion) throws CoreException {
- // By default, classpath container initializers do not accept updating containers
+ // By default, loadpath container initializers do not accept updating containers
}
/**
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
@@ -37,17 +37,17 @@
public abstract class LoadpathContainerInitializer {
/**
- * Creates a new classpath container initializer.
+ * Creates a new loadpath container initializer.
*/
public LoadpathContainerInitializer() {
@@ -37,17 +37,17 @@
*/
public LoadpathContainerInitializer() {
- // a classpath container initializer must have a public 0-argument constructor
+ // a loadpath container initializer must have a public 0-argument constructor
}
/**
|